Async Function Tools
====================

.. automodule:: aiotools.func

.. currentmodule:: aiotools.func

.. function:: aiotools.func.apartial(func, /, *args, **kwargs)

   .. deprecated:: 2.0

      Use :func:`functools.partial()` directly for async functions as well,
      since it began to work seamlessly as of Python 3.8.

.. autofunction:: aiotools.func.lru_cache
